#!/usr/bin/env python3

import re

SCSS = '../../src/stylesheet/_palette.scss'
LIGHT = set(['light-1', 'light-2'])
DARK = set(['dark-4', 'dark-5'])

colors = []
regex = re.compile('^\$(\w+)_([1-5]):\s*(#\w+);$')

# Parse colors
with open(SCSS, 'r') as scss:
    for line in scss:
        match = regex.match(line)
        if match == None:
            continue
        name = match.group(1)
        level = match.group(2)
        value = match.group(3)

        colors.append((name, level, value))

# Generate table
print('<table>')
print('  <tr>')
print('    <th></th>')
print('    <th>Name</th>')
print('    <th>Value</th>')
print('  </tr>')

for name, level, color in colors:
    variable = '--{}-{}'.format(name, level)

    classes = ''
    if variable in LIGHT:
        classes += ' light'
    if variable in DARK:
        classes += ' dark'

    print('  <tr>')
    print('    <td><div class="color-pill{}" style="background-color: {}"/></td>'.format(classes, color))
    print('    <td><tt>{}</tt></td>'.format(variable))
    print('    <td><tt>{}</tt></td>'.format(color))
    print('  </tr>')

print('</table>')




#!/usr/bin/env python3

import os
import re
import sys

def main(argv):
    ensure_types = []
    print('/* This file was generated by gen-public-types.py, do not edit it. */\n')

    # Run through the headers fed in to #include them and extract the ADW_TYPE_* macros
    for header in argv[1:]:
        print('#include "%s"' % os.path.basename(header))
        with open(header, 'r', encoding='utf-8') as file:
            for line in file:
                match = re.search(r'#define {1,}(ADW_TYPE_[A-Z0-9_]{1,}) {1,}.*', line)
                if match:
                    ensure_types.append(match.group(1))

    ensure_types.sort()

    print('#include "adw-main-private.h"\n')
    print('void')
    print('adw_init_public_types (void)')
    print('{')

    for gtype in ensure_types:
        print('  g_type_ensure (%s);' % gtype)

    print('}')

main(sys.argv)
